@@ -5,7 +5,7 @@
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="615"/>
+        <location filename="../datetime.cpp" line="612"/>
         <source>MX Date &amp; Time</source>
         <translation>MX Datum &amp; Zeit</translation>
     </message>
@@ -142,52 +142,52 @@
         <translation>Selektion nach Unten verschieben</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="450"/>
+        <location filename="../datetime.ui" line="449"/>
         <source>Move the selected item up</source>
         <translation>Selektion nach Oben verschieben</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="461"/>
+        <location filename="../datetime.ui" line="459"/>
         <source>Remove the current item from the list</source>
         <translation>Selektion von der Liste entfernen</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="472"/>
+        <location filename="../datetime.ui" line="470"/>
         <source>Add an item to the list</source>
         <translation>Eintrag zur Liste hinzufügen</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="498"/>
+        <location filename="../datetime.ui" line="496"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Die Uhrzeit automatisch mit NTP Servern abgleichen</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="505"/>
+        <location filename="../datetime.ui" line="503"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Die Uhrzeit jetzt mit NTP Servern abgleichen</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="508"/>
+        <location filename="../datetime.ui" line="506"/>
         <source>Update Now</source>
         <translation>Jetzt abgleichen</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="520"/>
+        <location filename="../datetime.ui" line="518"/>
         <source>List of NTP servers to use.</source>
         <translation>Liste der benutzen NTP Server</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="536"/>
+        <location filename="../datetime.ui" line="534"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="541"/>
+        <location filename="../datetime.ui" line="539"/>
         <source>Address</source>
         <translation>Adresse</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="546"/>
+        <location filename="../datetime.ui" line="544"/>
         <source>Options</source>
         <translation>Einstellungen</translation>
     </message>
@@ -218,47 +218,47 @@
         <translation>Die %1 Zeit konnte von %2 nicht übernommen werden.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="361"/>
+        <location filename="../datetime.cpp" line="360"/>
         <source>Updating...</source>
         <translation>Abgleich...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="375"/>
+        <location filename="../datetime.cpp" line="373"/>
         <source>The system clock was updated successfully.</source>
         <translation>Die Systemzeit wurde erfolgreich synchronisiert.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="377"/>
+        <location filename="../datetime.cpp" line="375"/>
         <source>The system clock could not be updated.</source>
         <translation>Die Systemzeit konnte nicht synchronisiert werden.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="379"/>
+        <location filename="../datetime.cpp" line="377"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>Keiner der NTP Server aus der Liste ist aktiviert.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="615"/>
+        <location filename="../datetime.cpp" line="612"/>
         <source>About MX Date &amp; Time</source>
         <translation>Über MX Datum &amp; Zeit</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="616"/>
+        <location filename="../datetime.cpp" line="613"/>
         <source>Version: </source>
         <translation>Version:</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="617"/>
+        <location filename="../datetime.cpp" line="614"/>
         <source>GUI program for setting the time and date in MX Linux</source>
-        <translation>Grafisches Tool zum Einstellen des Datum und der Uhrzeit in MX Linux</translation>
+        <translation>Grafische Anwendung, um Datum und Uhrzeit in MX Linux einzustellen</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="619"/>
+        <location filename="../datetime.cpp" line="616"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="621"/>
+        <location filename="../datetime.cpp" line="618"/>
         <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
@@ -268,7 +268,7 @@
     </message>
     <message>
         <source>Changelog</source>
-        <translation type="vanished">Changelog</translation>
+        <translation type="vanished">Änderungsprotokoll</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -276,10 +276,10 @@
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;Close</translation>
+        <translation type="vanished">&amp;Schließen</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="627"/>
+        <location filename="../datetime.cpp" line="624"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX Datum &amp; Zeit Hilfe</translation>
     </message>
@@ -295,12 +295,12 @@
         <location filename="../about.cpp" line="53"/>
         <location filename="../about.cpp" line="61"/>
         <source>Changelog</source>
-        <translation type="unfinished">Changelog</translation>
+        <translation type="unfinished">Änderungsprotokoll</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="73"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Close</translation>
+        <translation type="unfinished">&amp;Schließen</translation>
     </message>
 </context>
 </TS>
